Python модуль для генерации пароля

Инструкция:

1. Чтобы указать длину пароля используйте параметр length. Если укажите параметр length ниже 0 то приведет к ошибке InvalidLengthError.

А дальше мне лень писать.